/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_cs extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ADP", "ADP" },
            { "AED", "AED" },
            { "AFA", "AFA" },
            { "AFN", "AFN" },
            { "ALK", "ALK" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AOK", "AOK" },
            { "AON", "AON" },
            { "AOR", "AOR" },
            { "ARA", "ARA" },
            { "ARL", "ARL" },
            { "ARM", "ARM" },
            { "ARP", "ARP" },
            { "ARS", "ARS" },
            { "ATS", "ATS" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZM", "AZM" },
            { "AZN", "AZN" },
            { "BAD", "BAD" },
            { "BAM", "BAM" },
            { "BAN", "BAN" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BEC", "BEC" },
            { "BEF", "BEF" },
            { "BEL", "BEL" },
            { "BGL", "BGL" },
            { "BGM", "BGM" },
            { "BGN", "BGN" },
            { "BGO", "BGO" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BOL", "BOL" },
            { "BOP", "BOP" },
            { "BOV", "BOV" },
            { "BRB", "BRB" },
            { "BRC", "BRC" },
            { "BRE", "BRE" },
            { "BRN", "BRN" },
            { "BRR", "BRR" },
            { "BRZ", "BRZ" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BUK", "BUK" },
            { "BWP", "BWP" },
            { "BYB", "BYB" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHE", "CHE" },
            { "CHF", "CHF" },
            { "CHW", "CHW" },
            { "CLE", "CLE" },
            { "CLF", "CLF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "CNX", "CNX" },
            { "COP", "COP" },
            { "COU", "COU" },
            { "CRC", "CRC" },
            { "CSD", "CSD" },
            { "CSK", "K\u010ds" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CYP", "CYP" },
            { "CZK", "K\u010d" },
            { "DDM", "DDM" },
            { "DEM", "DEM" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "ECS", "ECS" },
            { "ECV", "ECV" },
            { "EEK", "EEK" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESA", "ESA" },
            { "ESB", "ESB" },
            { "ESP", "ESP" },
            { "ETB", "ETB" },
            { "FIM", "FIM" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "FRF", "FRF" },
            { "GEK", "GEK" },
            { "GEL", "GEL" },
            { "GHC", "GHC" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GNS", "GNS" },
            { "GQE", "GQE" },
            { "GRD", "GRD" },
            { "GTQ", "GTQ" },
            { "GWE", "GWE" },
            { "GWP", "GWP" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRD", "HRD" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IEP", "IEP" },
            { "ILP", "ILP" },
            { "ILR", "ILR" },
            { "ILS", "ILS" },
            { "INR", "INR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISJ", "ISJ" },
            { "ISK", "ISK" },
            { "ITL", "ITL" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRH", "KRH" },
            { "KRO", "KRO" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LTL", "LTL" },
            { "LTT", "LTT" },
            { "LUC", "LUC" },
            { "LUF", "LUF" },
            { "LUL", "LUL" },
            { "LVL", "LVL" },
            { "LVR", "LVR" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MAF", "MAF" },
            { "MCF", "MCF" },
            { "MDC", "MDC" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MGF", "MGF" },
            { "MKD", "MKD" },
            { "MKN", "MKN" },
            { "MLF", "MLF" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MTL", "MTL" },
            { "MTP", "MTP" },
            { "MUR", "MUR" },
            { "MVP", "MVP" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXP", "MXP" },
            { "MXV", "MXV" },
            { "MYR", "MYR" },
            { "MZE", "MZE" },
            { "MZM", "MZM" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIC", "NIC" },
            { "NIO", "NIO" },
            { "NLG", "NLG" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEI", "PEI" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PLZ", "PLZ" },
            { "PTE", "PTE" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RHD", "RHD" },
            { "ROL", "ROL" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RUR", "RUR" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDD", "SDD" },
            { "SDG", "SDG" },
            { "SDP", "SDP" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SIT", "SIT" },
            { "SKK", "SKK" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SRG", "SRG" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SUR", "SUR" },
            { "SVC", "SVC" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJR", "TJR" },
            { "TJS", "TJS" },
            { "TMM", "TMM" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TPE", "TPE" },
            { "TRL", "TRL" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UAK", "UAK" },
            { "UGS", "UGS" },
            { "UGX", "UGX" },
            { "USN", "USN" },
            { "USS", "USS" },
            { "UYI", "UYI" },
            { "UYP", "UYP" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEB", "VEB" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VND", "VND" },
            { "VNN", "VNN" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XAG", "XAG" },
            { "XAU", "XAU" },
            { "XBA", "XBA" },
            { "XBB", "XBB" },
            { "XBC", "XBC" },
            { "XBD", "XBD" },
            { "XDR", "XDR" },
            { "XEU", "ECU" },
            { "XFO", "XFO" },
            { "XFU", "XFU" },
            { "XPD", "XPD" },
            { "XPT", "XPT" },
            { "XRE", "XRE" },
            { "XSU", "XSU" },
            { "XTS", "XTS" },
            { "XUA", "XUA" },
            { "XXX", "XXX" },
            { "YDD", "YDD" },
            { "YER", "YER" },
            { "YUD", "YUD" },
            { "YUM", "YUM" },
            { "YUN", "YUN" },
            { "YUR", "YUR" },
            { "ZAL", "ZAL" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "ZRN", "ZRN" },
            { "ZRZ", "ZRZ" },
            { "ZWD", "ZWD" },
            { "ZWL", "ZWL" },
            { "ZWR", "ZWR" },
            { "adp", "andorrsk\u00e1 peseta" },
            { "aed", "SAE dirham" },
            { "afa", "afgh\u00e1nsk\u00fd afgh\u00e1n (1927\u20132002)" },
            { "afn", "afgh\u00e1nsk\u00fd afgh\u00e1n" },
            { "alk", "alb\u00e1nsk\u00fd lek (1946\u20131965)" },
            { "all", "alb\u00e1nsk\u00fd lek" },
            { "amd", "arm\u00e9nsk\u00fd dram" },
            { "ang", "nizozemskoantilsk\u00fd gulden" },
            { "aoa", "angolsk\u00e1 kwanza" },
            { "aok", "angolsk\u00e1 kwanza (1977\u20131991)" },
            { "aon", "angolsk\u00e1 kwanza (1990\u20132000)" },
            { "aor", "angolsk\u00e1 kwanza (1995\u20131999)" },
            { "ara", "argentinsk\u00fd austral" },
            { "arl", "argentinsk\u00e9 peso ley (1970\u20131983)" },
            { "arm", "argentinsk\u00e9 peso (1881\u20131970)" },
            { "arp", "argentinsk\u00e9 peso (1983\u20131985)" },
            { "ars", "argentinsk\u00e9 peso" },
            { "ats", "rakousk\u00fd \u0161ilink" },
            { "aud", "australsk\u00fd dolar" },
            { "awg", "arubsk\u00fd zlat\u00fd" },
            { "azm", "\u00e1zerb\u00e1jd\u017e\u00e1nsk\u00fd manat (1993\u20132006)" },
            { "azn", "\u00e1zerb\u00e1jd\u017e\u00e1nsk\u00fd manat" },
            { "bad", "bosensk\u00fd din\u00e1r (1992\u20131994)" },
            { "bam", "bosensk\u00e1 konvertibiln\u00ed marka" },
            { "ban", "bosensk\u00fd nov\u00fd din\u00e1r (1994\u20131997)" },
            { "bbd", "barbadosk\u00fd dolar" },
            { "bdt", "banglad\u00e9\u0161sk\u00e1 taka" },
            { "bec", "belgick\u00fd konvertibiln\u00ed frank" },
            { "bef", "belgick\u00fd frank" },
            { "bel", "belgick\u00fd finan\u010dn\u00ed frank" },
            { "bgl", "bulharsk\u00fd tvrd\u00fd leva" },
            { "bgm", "bulharsk\u00fd socialistick\u00fd leva" },
            { "bgn", "bulharsk\u00fd leva" },
            { "bgo", "bulharsk\u00fd lev (1879\u20131952)" },
            { "bhd", "bahrajnsk\u00fd din\u00e1r" },
            { "bif", "burundsk\u00fd frank" },
            { "bmd", "bermudsk\u00fd dolar" },
            { "bnd", "brunejsk\u00fd dolar" },
            { "bob", "bolivijsk\u00fd boliviano" },
            { "bol", "bolivijsk\u00fd boliviano (1863\u20131963)" },
            { "bop", "bolivijsk\u00e9 peso" },
            { "bov", "bolivijsk\u00fd mvdol" },
            { "brb", "brazilsk\u00e9 nov\u00e9 cruzeiro (1967\u20131986)" },
            { "brc", "brazilsk\u00e9 cruzado (1986\u20131989)" },
            { "bre", "brazilsk\u00e9 cruzeiro (1990\u20131993)" },
            { "brl", "brazilsk\u00fd real" },
            { "brn", "brazilsk\u00e9 nov\u00e9 cruzado (1989\u20131990)" },
            { "brr", "brazilsk\u00e9 cruzeiro (1993\u20131994)" },
            { "brz", "brazilsk\u00e9 cruzeiro (1942\u20131967)" },
            { "bsd", "bahamsk\u00fd dolar" },
            { "btn", "bh\u00fat\u00e1nsk\u00fd ngultrum" },
            { "buk", "barmsk\u00fd kyat" },
            { "bwp", "botswansk\u00e1 pula" },
            { "byb", "b\u011blorusk\u00fd rubl (1994\u20131999)" },
            { "byn", "b\u011blorusk\u00fd rubl" },
            { "byr", "b\u011blorusk\u00fd rubl (2000\u20132016)" },
            { "bzd", "belizsk\u00fd dolar" },
            { "cad", "kanadsk\u00fd dolar" },
            { "cdf", "kon\u017esk\u00fd frank" },
            { "che", "\u0161v\u00fdcarsk\u00e9 WIR-euro" },
            { "chf", "\u0161v\u00fdcarsk\u00fd frank" },
            { "chw", "\u0161v\u00fdcarsk\u00fd WIR-frank" },
            { "cle", "chilsk\u00e9 escudo" },
            { "clf", "chilsk\u00e1 \u00fa\u010detn\u00ed jednotka (UF)" },
            { "clp", "chilsk\u00e9 peso" },
            { "cnh", "\u010d\u00ednsk\u00fd j\u00fcan (offshore)" },
            { "cnx", "\u010d\u00ednsk\u00fd dolar \u010cLB" },
            { "cny", "\u010d\u00ednsk\u00fd j\u00fcan" },
            { "cop", "kolumbijsk\u00e9 peso" },
            { "cou", "kolumbijsk\u00e1 jednotka re\u00e1ln\u00e9 hodnoty" },
            { "crc", "kostarick\u00fd col\u00f3n" },
            { "csd", "srbsk\u00fd din\u00e1r (2002\u20132006)" },
            { "csk", "\u010deskoslovensk\u00e1 koruna" },
            { "cuc", "kub\u00e1nsk\u00e9 konvertibiln\u00ed peso" },
            { "cup", "kub\u00e1nsk\u00e9 peso" },
            { "cve", "kapverdsk\u00e9 escudo" },
            { "cyp", "kypersk\u00e1 libra" },
            { "czk", "\u010desk\u00e1 koruna" },
            { "ddm", "v\u00fdchodon\u011bmeck\u00e1 marka" },
            { "dem", "n\u011bmeck\u00e1 marka" },
            { "djf", "d\u017eibutsk\u00fd frank" },
            { "dkk", "d\u00e1nsk\u00e1 koruna" },
            { "dop", "dominik\u00e1nsk\u00e9 peso" },
            { "dzd", "al\u017e\u00edrsk\u00fd din\u00e1r" },
            { "ecs", "ekv\u00e1dorsk\u00fd sucre" },
            { "ecv", "ekv\u00e1dorsk\u00e1 jednotka konstantn\u00ed hodnoty" },
            { "eek", "estonsk\u00e1 koruna" },
            { "egp", "egyptsk\u00e1 libra" },
            { "ern", "eritrejsk\u00e1 nakfa" },
            { "esa", "\u0161pan\u011blsk\u00e1 peseta (\u201eA\u201c \u00fa\u010det)" },
            { "esb", "\u0161pan\u011blsk\u00e1 peseta (konvertibiln\u00ed \u00fa\u010det)" },
            { "esp", "\u0161pan\u011blsk\u00e1 peseta" },
            { "etb", "etiopsk\u00fd birr" },
            { "eur", "euro" },
            { "fim", "finsk\u00e1 marka" },
            { "fjd", "fid\u017eijsk\u00fd dolar" },
            { "fkp", "falklandsk\u00e1 libra" },
            { "frf", "francouzsk\u00fd frank" },
            { "gbp", "britsk\u00e1 libra" },
            { "gek", "gruz\u00ednsk\u00e9 kuponov\u00e9 lari" },
            { "gel", "gruz\u00ednsk\u00e9 lari" },
            { "ghc", "ghansk\u00fd cedi (1979\u20132007)" },
            { "ghs", "ghansk\u00fd cedi" },
            { "gip", "gibraltarsk\u00e1 libra" },
            { "gmd", "gambijsk\u00fd dalasi" },
            { "gnf", "guinejsk\u00fd frank" },
            { "gns", "guinejsk\u00fd syli" },
            { "gqe", "rovn\u00edkovoguinejsk\u00fd ekwele" },
            { "grd", "\u0159eck\u00e1 drachma" },
            { "gtq", "guatemalsk\u00fd quetzal" },
            { "gwe", "portugalskoguinejsk\u00e9 escudo" },
            { "gwp", "guinejsko-bissausk\u00e9 peso" },
            { "gyd", "guyansk\u00fd dolar" },
            { "hkd", "hongkongsk\u00fd dolar" },
            { "hnl", "hondurask\u00e1 lempira" },
            { "hrd", "chorvatsk\u00fd din\u00e1r" },
            { "hrk", "chorvatsk\u00e1 kuna" },
            { "htg", "haitsk\u00fd gourde" },
            { "huf", "ma\u010farsk\u00fd forint" },
            { "idr", "indon\u00e9sk\u00e1 rupie" },
            { "iep", "irsk\u00e1 libra" },
            { "ilp", "izraelsk\u00e1 libra" },
            { "ilr", "izraelsk\u00fd \u0161ekel (1980\u20131985)" },
            { "ils", "izraelsk\u00fd nov\u00fd \u0161ekel" },
            { "inr", "indick\u00e1 rupie" },
            { "iqd", "ir\u00e1ck\u00fd din\u00e1r" },
            { "irr", "\u00edr\u00e1nsk\u00fd rij\u00e1l" },
            { "isj", "islandsk\u00e1 koruna (1918\u20131981)" },
            { "isk", "islandsk\u00e1 koruna" },
            { "itl", "italsk\u00e1 lira" },
            { "jmd", "jamajsk\u00fd dolar" },
            { "jod", "jord\u00e1nsk\u00fd din\u00e1r" },
            { "jpy", "japonsk\u00fd jen" },
            { "kes", "ke\u0148sk\u00fd \u0161ilink" },
            { "kgs", "kyrgyzsk\u00fd som" },
            { "khr", "kambod\u017esk\u00fd riel" },
            { "kmf", "komorsk\u00fd frank" },
            { "kpw", "severokorejsk\u00fd won" },
            { "krh", "jihokorejsk\u00fd hwan (1953\u20131962)" },
            { "kro", "jihokorejsk\u00fd won (1945\u20131953)" },
            { "krw", "jihokorejsk\u00fd won" },
            { "kwd", "kuvajtsk\u00fd din\u00e1r" },
            { "kyd", "kajmansk\u00fd dolar" },
            { "kzt", "kaza\u0161sk\u00e9 tenge" },
            { "lak", "laosk\u00fd kip" },
            { "lbp", "libanonsk\u00e1 libra" },
            { "lkr", "sr\u00edlansk\u00e1 rupie" },
            { "lrd", "liberijsk\u00fd dolar" },
            { "lsl", "lesothsk\u00fd loti" },
            { "ltl", "litevsk\u00fd litas" },
            { "ltt", "litevsk\u00fd talonas" },
            { "luc", "lucembursk\u00fd konvertibiln\u00ed frank" },
            { "luf", "lucembursk\u00fd frank" },
            { "lul", "lucembursk\u00fd finan\u010dn\u00ed frank" },
            { "lvl", "loty\u0161sk\u00fd lat" },
            { "lvr", "loty\u0161sk\u00fd rubl" },
            { "lyd", "libyjsk\u00fd din\u00e1r" },
            { "mad", "marock\u00fd din\u00e1r" },
            { "maf", "marock\u00fd frank" },
            { "mcf", "monack\u00fd frank" },
            { "mdc", "moldavsk\u00fd kupon" },
            { "mdl", "moldavsk\u00fd leu" },
            { "mga", "madagaskarsk\u00fd ariary" },
            { "mgf", "madagaskarsk\u00fd frank" },
            { "mkd", "makedonsk\u00fd den\u00e1r" },
            { "mkn", "makedonsk\u00fd den\u00e1r (1992\u20131993)" },
            { "mlf", "malijsk\u00fd frank" },
            { "mmk", "myanmarsk\u00fd kyat" },
            { "mnt", "mongolsk\u00fd tugrik" },
            { "mop", "macajsk\u00e1 pataca" },
            { "mro", "maurit\u00e1nsk\u00e1 ouguiya (1973\u20132017)" },
            { "mru", "maurit\u00e1nsk\u00e1 ouguiya" },
            { "mtl", "maltsk\u00e1 lira" },
            { "mtp", "maltsk\u00e1 libra" },
            { "mur", "mauricijsk\u00e1 rupie" },
            { "mvp", "maledivsk\u00e1 rupie (1947\u20131981)" },
            { "mvr", "maledivsk\u00e1 rupie" },
            { "mwk", "malawijsk\u00e1 kwacha" },
            { "mxn", "mexick\u00e9 peso" },
            { "mxp", "mexick\u00e9 st\u0159\u00edbrn\u00e9 peso (1861\u20131992)" },
            { "mxv", "mexick\u00e1 investi\u010dn\u00ed jednotka" },
            { "myr", "malajsijsk\u00fd ringgit" },
            { "mze", "mosambick\u00fd escudo" },
            { "mzm", "mosambick\u00fd metical (1980\u20132006)" },
            { "mzn", "mozambick\u00fd metical" },
            { "nad", "namibijsk\u00fd dolar" },
            { "ngn", "nigerijsk\u00e1 naira" },
            { "nic", "nikaragujsk\u00e1 c\u00f3rdoba (1988\u20131991)" },
            { "nio", "nikaragujsk\u00e1 c\u00f3rdoba" },
            { "nlg", "nizozemsk\u00fd gulden" },
            { "nok", "norsk\u00e1 koruna" },
            { "npr", "nep\u00e1lsk\u00e1 rupie" },
            { "nzd", "novoz\u00e9landsk\u00fd dolar" },
            { "omr", "om\u00e1nsk\u00fd rij\u00e1l" },
            { "pab", "panamsk\u00e1 balboa" },
            { "pei", "peru\u00e1nsk\u00e1 inti" },
            { "pen", "peru\u00e1nsk\u00fd sol" },
            { "pes", "peru\u00e1nsk\u00fd sol (1863\u20131965)" },
            { "pgk", "papu\u00e1nsk\u00e1 nov\u00e1 kina" },
            { "php", "filip\u00ednsk\u00e9 peso" },
            { "pkr", "p\u00e1kist\u00e1nsk\u00e1 rupie" },
            { "pln", "polsk\u00fd zlot\u00fd" },
            { "plz", "polsk\u00fd zlot\u00fd (1950\u20131995)" },
            { "pte", "portugalsk\u00e9 escudo" },
            { "pyg", "paraguajsk\u00e9 guarani" },
            { "qar", "katarsk\u00fd rij\u00e1l" },
            { "rhd", "rhod\u00e9sk\u00fd dolar" },
            { "rol", "rumunsk\u00e9 leu (1952\u20132006)" },
            { "ron", "rumunsk\u00fd leu" },
            { "rsd", "srbsk\u00fd din\u00e1r" },
            { "rub", "rusk\u00fd rubl" },
            { "rur", "rusk\u00fd rubl (1991\u20131998)" },
            { "rwf", "rwandsk\u00fd frank" },
            { "sar", "sa\u00fadsk\u00fd rij\u00e1l" },
            { "sbd", "\u0161alamounsk\u00fd dolar" },
            { "scr", "seychelsk\u00e1 rupie" },
            { "sdd", "s\u00fad\u00e1nsk\u00fd din\u00e1r (1992\u20132007)" },
            { "sdg", "s\u00fad\u00e1nsk\u00e1 libra" },
            { "sdp", "s\u00fad\u00e1nsk\u00e1 libra (1957\u20131998)" },
            { "sek", "\u0161v\u00e9dsk\u00e1 koruna" },
            { "sgd", "singapursk\u00fd dolar" },
            { "shp", "svatohelensk\u00e1 libra" },
            { "sit", "slovinsk\u00fd tolar" },
            { "skk", "slovensk\u00e1 koruna" },
            { "sll", "sierro-leonsk\u00fd leone" },
            { "sos", "som\u00e1lsk\u00fd \u0161ilink" },
            { "srd", "surinamsk\u00fd dolar" },
            { "srg", "surinamsk\u00fd zlat\u00fd" },
            { "ssp", "jihos\u00fad\u00e1nsk\u00e1 libra" },
            { "std", "svatotom\u00e1\u0161sk\u00e1 dobra (1977\u20132017)" },
            { "stn", "svatotom\u00e1\u0161sk\u00e1 dobra" },
            { "sur", "sov\u011btsk\u00fd rubl" },
            { "svc", "salvadorsk\u00fd col\u00f3n" },
            { "syp", "syrsk\u00e1 libra" },
            { "szl", "svazijsk\u00fd lilangeni" },
            { "thb", "thajsk\u00fd baht" },
            { "tjr", "t\u00e1d\u017eick\u00fd rubl" },
            { "tjs", "t\u00e1d\u017eick\u00e9 somoni" },
            { "tmm", "turkmensk\u00fd manat (1993\u20132009)" },
            { "tmt", "turkmensk\u00fd manat" },
            { "tnd", "tunisk\u00fd din\u00e1r" },
            { "top", "ton\u017esk\u00e1 paanga" },
            { "tpe", "timorsk\u00e9 escudo" },
            { "trl", "tureck\u00e1 lira (1922\u20132005)" },
            { "try", "tureck\u00e1 lira" },
            { "ttd", "trinidadsk\u00fd dolar" },
            { "twd", "tchajwansk\u00fd dolar" },
            { "tzs", "tanzansk\u00fd \u0161ilink" },
            { "uah", "ukrajinsk\u00e1 h\u0159ivna" },
            { "uak", "ukrajinsk\u00fd karbovanec" },
            { "ugs", "ugandsk\u00fd \u0161ilink (1966\u20131987)" },
            { "ugx", "ugandsk\u00fd \u0161ilink" },
            { "usd", "americk\u00fd dolar" },
            { "usn", "americk\u00fd dolar (p\u0159\u00ed\u0161t\u00ed den)" },
            { "uss", "americk\u00fd dolar (t\u00fd\u017e den)" },
            { "uyi", "uruguaysk\u00e9 peso (v indexovan\u00fdch jednotk\u00e1ch)" },
            { "uyp", "uruguaysk\u00e9 peso (1975\u20131993)" },
            { "uyu", "uruguaysk\u00e9 peso" },
            { "uzs", "uzbeck\u00fd sum" },
            { "veb", "venezuelsk\u00fd bol\u00edvar (1871\u20132008)" },
            { "vef", "venezuelsk\u00fd bol\u00edvar (2008\u20132018)" },
            { "ves", "venezuelsk\u00fd bol\u00edvar" },
            { "vnd", "vietnamsk\u00fd dong" },
            { "vnn", "vietnamsk\u00fd dong (1978\u20131985)" },
            { "vuv", "vanuatsk\u00fd vatu" },
            { "wst", "samojsk\u00e1 tala" },
            { "xaf", "CFA/BEAC frank" },
            { "xag", "st\u0159\u00edbro" },
            { "xau", "zlato" },
            { "xba", "evropsk\u00e1 sm\u00ed\u0161en\u00e1 jednotka" },
            { "xbb", "evropsk\u00e1 pen\u011b\u017en\u00ed jednotka" },
            { "xbc", "evropsk\u00e1 jednotka \u00fa\u010dtu 9 (XBC)" },
            { "xbd", "evropsk\u00e1 jednotka \u00fa\u010dtu 17 (XBD)" },
            { "xcd", "v\u00fdchodokaribsk\u00fd dolar" },
            { "xdr", "SDR" },
            { "xeu", "evropsk\u00e1 m\u011bnov\u00e1 jednotka" },
            { "xfo", "francouzsk\u00fd zlat\u00fd frank" },
            { "xfu", "francouzsk\u00fd UIC frank" },
            { "xof", "CFA/BCEAO frank" },
            { "xpd", "palladium" },
            { "xpf", "CFP frank" },
            { "xpt", "platina" },
            { "xre", "k\u00f3d fond\u016f RINET" },
            { "xsu", "sucre" },
            { "xts", "k\u00f3d zvl\u00e1\u0161\u0165 vyhrazen\u00fd pro testovac\u00ed \u00fa\u010dely" },
            { "xxx", "nezn\u00e1m\u00e1 m\u011bna" },
            { "ydd", "jemensk\u00fd din\u00e1r" },
            { "yer", "jemensk\u00fd rij\u00e1l" },
            { "yud", "jugosl\u00e1vsk\u00fd din\u00e1r (1966\u20131990)" },
            { "yum", "jugosl\u00e1vsk\u00fd nov\u00fd din\u00e1r (1994\u20132002)" },
            { "yun", "jugosl\u00e1vsk\u00fd konvertibiln\u00ed din\u00e1r (1990\u20131992)" },
            { "yur", "jugosl\u00e1vsk\u00fd reformovan\u00fd din\u00e1r (1992\u20131993)" },
            { "zal", "jihoafrick\u00fd finan\u010dn\u00ed rand" },
            { "zar", "jihoafrick\u00fd rand" },
            { "zmk", "zambijsk\u00e1 kwacha (1968\u20132012)" },
            { "zmw", "zambijsk\u00e1 kwacha" },
            { "zrn", "zairsk\u00fd nov\u00fd zaire (1993\u20131998)" },
            { "zrz", "zairsk\u00fd zaire (1971\u20131993)" },
            { "zwd", "zimbabwsk\u00fd dolar (1980\u20132008)" },
            { "zwl", "zimbabwsk\u00fd dolar (2009)" },
            { "zwr", "zimbabwsk\u00fd dolar (2008)" },
        };
        return data;
    }
}
